@@ -4,7 +4,7 @@ use 5.010;
 use Moo 1.004005;
 use namespace::autoclean;
 
-our $VERSION = '1.007000';
+our $VERSION = '1.008000';
 
 use HTTP::Headers ();
 use HTTP::Request ();
@@ -21,6 +21,7 @@ use WebService::MinFraud::Error::WebService;
 use WebService::MinFraud::Model::Factors;
 use WebService::MinFraud::Model::Insights;
 use WebService::MinFraud::Model::Score;
+use WebService::MinFraud::Model::Chargeback;
 use WebService::MinFraud::Types
     qw( JSONObject MaxMindID MaxMindLicenseKey Str URIObject UserAgentObject );
 use WebService::MinFraud::Validator;
@@ -39,8 +40,7 @@ has _base_uri => (
     isa     => URIObject,
     builder => sub {
         my $self = shift;
-        URI->new(
-            $self->uri_scheme . '://' . $self->host . '/minfraud/v2.0' );
+        URI->new( $self->uri_scheme . '://' . $self->host . '/minfraud' );
     },
 );
 has host => (
@@ -119,6 +119,7 @@ sub factors {
     my $self = shift;
 
     return $self->_response_for(
+        'v2.0',
         'factors',
         'WebService::MinFraud::Model::Factors', @_,
     );
@@ -128,6 +129,7 @@ sub insights {
     my $self = shift;
 
     return $self->_response_for(
+        'v2.0',
         'insights',
         'WebService::MinFraud::Model::Insights', @_,
     );
@@ -137,22 +139,42 @@ sub score {
     my $self = shift;
 
     return $self->_response_for(
+        'v2.0',
         'score',
         'WebService::MinFraud::Model::Score', @_,
     );
 }
 
+sub chargeback {
+    my $self = shift;
+
+    return $self->_response_for(
+        undef,
+        'chargeback',
+        'WebService::MinFraud::Model::Chargeback', @_,
+    );
+}
+
 sub _response_for {
-    my ( $self, $path, $model_class, $content ) = @_;
+    my ( $self, $version, $path, $model_class, $content ) = @_;
 
     $content = $self->_remove_trivial_hash_values($content);
+
     $self->_fix_booleans($content);
-    $self->_validator->validate_request($content);
-    my $uri = $self->_base_uri->clone;
-    $uri->path_segments( $uri->path_segments, $path );
+
+    my $uri           = $self->_base_uri->clone;
+    my @path_segments = ( $uri->path_segments, );
+    push @path_segments, $version if $version;
+    push @path_segments, $path;
+    $uri->path_segments(@path_segments);
+
+    $self->_validator->validate_request( $content, $path );
     my $request = HTTP::Request->new(
         'POST', $uri,
-        HTTP::Headers->new( Accept => 'application/json' ),
+        HTTP::Headers->new(
+            Accept         => 'application/json',
+            'Content-Type' => 'application/json'
+        ),
         $self->_json->encode($content)
     );
 
@@ -164,6 +186,9 @@ sub _response_for {
         my $body = $self->_handle_success( $response, $uri );
         return $model_class->new( %{$body}, locales => $self->locales, );
     }
+    elsif ( $response->code == 204 ) {
+        return $model_class->new;
+    }
     else {
         # all other error codes throw an exception
         $self->_handle_error_status( $response, $uri );
@@ -185,7 +210,10 @@ sub _response_for {
 
         for my $boolean (@Booleans) {
             my ( $object, $key ) = @{$boolean};
-            next unless exists $content->{$object}{$key};
+            if (   !exists $content->{$object}
+                || !exists $content->{$object}{$key} ) {
+                next;
+            }
 
             $content->{$object}{$key}
                 = $content->{$object}{$key}
@@ -314,7 +342,7 @@ WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insight
 
 =head1 VERSION
 
-version 1.007000
+version 1.008000
 
 =head1 SYNOPSIS
 
@@ -349,12 +377,27 @@ version 1.007000
   my $factors = $client->factors( $request );
   say $factors->subscores->ip_tenure;
 
+
+  # Request HashRef must contain an 'ip_address' key containing  a valid
+  # IPv4 or IPv6 address. All other keys/values are optional; see other modules
+  # in minFraud Perl API distribution for details.
+
+  $request = { ip_address => '24.24.24.24' };
+
+  # Use the chargeback client method to submit an IP address back to Maxmind.
+  # The chargeback api does not return any content from the server.
+
+  my $chargeback = $client->chargeback( $request );
+  if ($chargeback->isa('WebService::MinFraud::Model::Chargeback')) {
+    say 'Successfully submitted chargeback';
+  }
+
 =head1 DESCRIPTION
 
-This class provides a client API for the MaxMind minFraud Score, Insights, and
-Factors web services. The B<Insights> service returns more data about a
-transaction than the B<Score> service. See the
-L<API documentation|https://dev.maxmind.com/minfraud/>
+This class provides a client API for the MaxMind minFraud Score, Insights
+Factors web services, and the Chargeback web service. The B<Insights>
+service returns more data about a transaction than the B<Score> service.
+See the L<API documentation|https://dev.maxmind.com/minfraud/>
 for more details.
 
 Each web service is represented by a different model class, and
@@ -485,19 +528,23 @@ described below.
 
 The request methods are passed a HashRef as the only argument. See the L</SYNOPSIS> and L<WebService::MinFraud::Example> for detailed usage examples. Some important notes regarding values passed to the minFraud web service via the Perl API are described below.
 
-=head2 device => ip_address
+=head2 device => ip_address or ip_address
 
 This must be a valid IPv4 or IPv6 address in presentation format, i.e.,
 dotted-quad notation or the IPv6 hexadecimal-colon notation.
 
 =head1 REQUEST METHODS
 
-All of the request methods require a device ip_address. See the
-L<API documentation|https://dev.maxmind.com/minfraud/>
+All of the fraud service request methods require a device ip_address. See the
+L<API documentation for fraud services|https://dev.maxmind.com/minfraud/>
 for details on all the values that can be part of the request. Portions of the
 request hash with undefined and empty string values are automatically removed
 from the request.
 
+The chargeback request method requires an ip_address. See the
+L<API documentation for chargeback|https:://dev.maxmind.com/minfraud/chargeback/>
+for details on all the values that can be part of the request.
+
 =head2 score
 
 This method calls the minFraud Score web service. It returns a
@@ -513,6 +560,11 @@ L<WebService::MinFraud::Model::Insights> object.
 This method calls the minFraud Factors web service. It returns a
 L<WebService::MinFraud::Model::Factors> object.
 
+=head2 chargeback
+
+This method calls the minFraud Chargeback web service. It returns a
+L<WebService::MinFraud::Model::Chargeback> object.
+
 =head1 User-Agent HEADER
 
 Requests by the minFraud Perl API will have a User-Agent header containing the
